/**
 * PrintInfo.hpp
 *
 * This file is part of the LibTiePie programming examples.
 *
 * Find more information on http://www.tiepie.com/LibTiePie .
 */

#ifndef _PRINTINFO_HPP_
#define _PRINTINFO_HPP_

#include <libtiepie-hw.hpp>

// Print library info:
void printLibraryInfo();

// Print device info:
void printDeviceInfo(const TiePie::Hardware::Device& dev);

// Print oscilloscope info:
void printOscilloscopeInfo(const TiePie::Hardware::Oscilloscope& scp);

// Print generator info:
void printGeneratorInfo(const TiePie::Hardware::Generator& gen);

// Print server info:
void printServerInfo(const TiePie::Hardware::Server& srv);

// Print trigger input info:
void printTriggerInputsInfo(const TiePie::Hardware::TriggerInputs& triggerInputs);

// Print trigger output info:
void printTriggerOutputsInfo(const TiePie::Hardware::TriggerOutputs& triggerOutputs);

// String conversion functions:
std::string generatorModeToStr(const uint64_t generatorModes);
std::string clockOutputToStr(const uint32_t clockOutputs);
std::string clockSourceToStr(const uint32_t clockSources);
std::string connectorTypeToStr(const uint32_t connectorTypes);
std::string dateToStr(const tiepie_hw_date& date);
std::string versionToStr(const tiepie_hw_version& version);
std::string couplingToStr(const uint64_t couplings);
std::string dataRawTypeToStr(const uint32_t dataRawTypes);
std::string deviceTypeToStr(const uint32_t deviceTypes);
std::string frequencyModeToStr(const uint32_t frequencyModes);
std::string measureModeToStr(const uint32_t dwMeasureModes);
std::string autoResolutionModeToStr(const uint32_t autoResolutions);
std::string signalTypeToStr(const uint32_t signalTypes);
std::string triggerConditionToStr(const uint32_t triggerConditions);
std::string triggerKindToStr(const uint64_t triggerKinds);
std::string triggerLevelModeToStr(const uint32_t triggerLevelModes);
std::string triggerOutputEventToStr(const uint64_t triggerEvents);
std::string boolToStr(const bool value);

#endif
